@@ -51,5 +51,7 @@ def from_load(load):
 	trans_data['pickup_open_time'] = load.pickup_open_time
 	trans_data['pickup_close_time'] = load.pickup_close_time
 	trans_data['freight_hub_load_id'] = load.id
+	if load.special_instructions:
+		trans_data['comments'] = load.special_instructions
 	transaction = Transaction(**trans_data)
 	return transaction
